@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -51,8 +51,7 @@ alias_format_str (char *dest, size_t destlen, char op, const char *src,
       snprintf (dest, destlen, tmp, alias->del ? "D" : " ");
       break;
     case 'a':
-      snprintf (tmp, sizeof (tmp), "%%%ss", fmt);
-      snprintf (dest, destlen, tmp, alias->name);
+      mutt_format_s (dest, destlen, fmt, alias->name);
       break;
     case 'r':
       adr[0] = 0;
@@ -103,7 +102,13 @@ static int alias_SortAddress (const void *a, const void *b)
   ADDRESS *pb = (*(ALIAS **) b)->addr;
   int r;
 
-  if (pa->personal)
+  if (pa == pb)
+    r = 0;
+  else if (pa == NULL)
+    r = -1;
+  else if (pb == NULL)
+    r = 1;
+  else if (pa->personal)
   { 
     if (pb->personal)
       r = mutt_strcasecmp (pa->personal, pb->personal);
@@ -226,6 +231,6 @@ new_aliases:
     rfc822_write_address (buf, buflen, AliasTable[t]->addr);
 
   mutt_menuDestroy (&menu);
-  safe_free ((void **) &AliasTable);
+  FREE (&AliasTable);
   
 }
