@@ -141,16 +141,16 @@ void mutt_expand_aliases_env (ENVELOPE *env)
 
 /* 
  * if someone has an address like
- *	From: Michael `/bin/rm -f ~` Elkins <me@cs.hmc.edu>
+ *	From: Michael `/bin/rm -f ~` Elkins <me@mutt.org>
  * and the user creates an alias for this, Mutt could wind up executing
  * the backtics because it writes aliases like
- *	alias me Michael `/bin/rm -f ~` Elkins <me@cs.hmc.edu>
+ *	alias me Michael `/bin/rm -f ~` Elkins <me@mutt.org>
  * To avoid this problem, use a backslash (\) to quote any backtics.  We also
  * need to quote backslashes as well, since you could defeat the above by
  * doing
- *	From: Michael \`/bin/rm -f ~\` Elkins <me@cs.hmc.edu>
+ *	From: Michael \`/bin/rm -f ~\` Elkins <me@mutt.org>
  * since that would get aliased as
- *	alias me Michael \\`/bin/rm -f ~\\` Elkins <me@cs.hmc.edu>
+ *	alias me Michael \\`/bin/rm -f ~\\` Elkins <me@mutt.org>
  * which still gets evaluated because the double backslash is not a quote.
  * 
  * Additionally, we need to quote ' and " characters - otherwise, mutt will
@@ -469,7 +469,7 @@ int mutt_alias_complete (char *s, size_t buflen)
   {
     a_cur = a_list;
     a_list = a_list->next;
-    safe_free ((void **) &a_cur);
+    FREE (&a_cur);
   }
 
   /* remove any aliases marked for deletion */
