@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@does-not-exist.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -156,13 +156,13 @@ int mutt_compose_attachment (BODY *a)
 	      b->parameter = NULL;
 	    }
 	    if (b->description) {
-	      safe_free ((void **) &a->description);
+	      FREE (&a->description);
 	      a->description = b->description;
 	      b->description = NULL;
 	    }
 	    if (b->form_name)
 	    {
-	      safe_free ((void **) &a->form_name);
+	      FREE (&a->form_name);
 	      a->form_name = b->form_name;
 	      b->form_name = NULL;
 	    }
@@ -356,9 +356,9 @@ void mutt_check_lookup_list (BODY *b, char *type, int len)
         b->filename, type));
     }
     if (tmp.subtype) 
-      safe_free ((void **) &tmp.subtype);
+      FREE (&tmp.subtype);
     if (tmp.xtype) 
-      safe_free ((void **) &tmp.xtype);
+      FREE (&tmp.xtype);
     }
   }
 }
