@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -179,9 +179,9 @@ int mutt_parse_mailboxes (BUFFER *path, BUFFER *s, unsigned long data, BUFFER *e
     {
       for (tmp = &Incoming; *tmp;)
       {
-        safe_free((void **)&((*tmp)->path));
+        FREE (&((*tmp)->path));
         tmp1=(*tmp)->next;
-        safe_free((void **)tmp);
+        FREE (tmp);
         *tmp=tmp1;
       }
       return 0;
@@ -203,9 +203,9 @@ int mutt_parse_mailboxes (BUFFER *path, BUFFER *s, unsigned long data, BUFFER *e
     {
       if(*tmp)
       {
-        safe_free((void **)&((*tmp)->path));
+        FREE (&((*tmp)->path));
         tmp1=(*tmp)->next;
-        safe_free((void **)tmp);
+        FREE (tmp);
         *tmp=tmp1;
       }
       continue;
