@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2002 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -124,8 +124,8 @@ static void mutt_free_color_line(COLOR_LINE **l,
   
   regfree(&tmp->rx);
   mutt_pattern_free(&tmp->color_pattern);
-  safe_free((void **)&tmp->pattern);
-  safe_free((void **)l);
+  FREE (&tmp->pattern);
+  FREE (l);
 }
 
 void ci_start_color (void)
@@ -275,7 +275,7 @@ void mutt_free_color (int fg, int bg)
       if (p == ColorList)
       {
 	ColorList = ColorList->next;
-	safe_free ((void **) &p);
+	FREE (&p);
 	return;
       }
       q = ColorList;
@@ -284,7 +284,7 @@ void mutt_free_color (int fg, int bg)
 	if (q->next == p)
 	{
 	  q->next = p->next;
-	  safe_free ((void **) &p);
+	  FREE (&p);
 	  return;
 	}
 	q = q->next;
@@ -392,7 +392,7 @@ _mutt_parse_uncolor (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err,
 
   if(
 #ifdef HAVE_COLOR
-     (parse_uncolor && !has_colors())
+     (parse_uncolor && !option(OPTNOCURSES) && !has_colors())
      || (!parse_uncolor && has_colors())
 #else
      parse_uncolor
@@ -508,7 +508,22 @@ add_pattern (COLOR_LINE **top, const char *s, int sensitive,
     char buf[STRING];
 
     tmp = mutt_new_color_line ();
-    if ((r = REGCOMP (&tmp->rx, s, (sensitive ? mutt_which_case (s) : REG_ICASE))) != 0)
+    if (is_index) 
+    {
+      int i;
+
+      strfcpy(buf, NONULL(s), sizeof(buf));
+      mutt_check_simple (buf, sizeof (buf), NONULL(SimpleSearch));
+      if((tmp->color_pattern = mutt_pattern_comp (buf, M_FULL_MSG, err)) == NULL)
+      {
+	mutt_free_color_line(&tmp, 1);
+	return -1;
+      }
+      /* force re-caching of index colors */
+      for (i = 0; Context && i < Context->msgcount; i++)
+	Context->hdrs[i]->pair = 0;
+    }
+    else if ((r = REGCOMP (&tmp->rx, s, (sensitive ? mutt_which_case (s) : REG_ICASE))) != 0)
     {
       regerror (r, &tmp->rx, err->data, err->dsize);
       mutt_free_color_line(&tmp, 1);
@@ -524,21 +539,6 @@ add_pattern (COLOR_LINE **top, const char *s, int sensitive,
       attr |= mutt_alloc_color (fg, bg);
     }
 #endif
-    if (is_index) 
-    {
-      int i;
-
-      strfcpy(buf, NONULL(tmp->pattern), sizeof(buf));
-      mutt_check_simple (buf, sizeof (buf), NONULL(SimpleSearch));
-      if((tmp->color_pattern = mutt_pattern_comp (buf, M_FULL_MSG, err)) == NULL)
-      {
-	mutt_free_color_line(&tmp, 1);
-	return -1;
-      }
-      /* force re-caching of index colors */
-      for (i = 0; Context && i < Context->msgcount; i++)
-	Context->hdrs[i]->pair = 0;
-    }
     tmp->pair = attr;
     *top = tmp;
   }
@@ -633,17 +633,17 @@ parse_attr_spec(BUFFER *buf, BUFFER *s, int *fg, int *bg, int *attr, BUFFER *err
 
   mutt_extract_token (buf, s, 0);
 
-  if (mutt_strcasecmp ("bold", buf->data) == 0)
+  if (ascii_strcasecmp ("bold", buf->data) == 0)
     *attr |= A_BOLD;
-  else if (mutt_strcasecmp ("underline", buf->data) == 0)
+  else if (ascii_strcasecmp ("underline", buf->data) == 0)
     *attr |= A_UNDERLINE;
-  else if (mutt_strcasecmp ("none", buf->data) == 0)
+  else if (ascii_strcasecmp ("none", buf->data) == 0)
     *attr = A_NORMAL;
-  else if (mutt_strcasecmp ("reverse", buf->data) == 0)
+  else if (ascii_strcasecmp ("reverse", buf->data) == 0)
     *attr |= A_REVERSE;
-  else if (mutt_strcasecmp ("standout", buf->data) == 0)
+  else if (ascii_strcasecmp ("standout", buf->data) == 0)
     *attr |= A_STANDOUT;
-  else if (mutt_strcasecmp ("normal", buf->data) == 0)
+  else if (ascii_strcasecmp ("normal", buf->data) == 0)
     *attr = A_NORMAL; /* needs use = instead of |= to clear other bits */
   else
   {
