@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -29,10 +29,30 @@
 
 #ifdef HAVE_PGP
 #define M_CM_DECODE_PGP	(1<<8)	/* used for decoding PGP messages */
-#define M_CM_VERIFY	(1<<9)	/* do signature verification */
+#define M_CM_DECODE_CRYPT	(1<<8)
 #endif
 
 
+#ifdef HAVE_SMIME
+#ifdef M_CM_DECODE_CRYPT
+#undef M_CM_DECODE_CRYPT
+#endif
+#define M_CM_DECODE_SMIME	(1<<9)	/* used for decoding S/MIME messages */
+#ifdef HAVE_PGP
+#undef M_CM_DECODE_CRYPT
+#define M_CM_DECODE_CRYPT  (M_CM_DECODE_PGP | M_CM_DECODE_SMIME)
+#else
+#define M_CM_DECODE_CRYPT	(1<<9)	/* used for decoding S/MIME messages */
+#endif
+#endif
+
+
+#if defined(HAVE_PGP) || defined(HAVE_SMIME)
+#define M_CM_VERIFY	(1<<10)	/* do signature verification */
+#endif
+
+
+
 
 int mutt_copy_hdr (FILE *, FILE *, long, long, int, const char *);
 
