@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 1996,1997 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
- * Copyright (C) 2001  Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1996,1997 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@does-not-exist.org>
+ * Copyright (C) 2001  Thomas Roessler <roessler@does-not-exist.org>
  *                     Oliver Ehli <elmy@acm.org>
  *
  *     This program is free software; you can redistribute it and/or modify
@@ -189,10 +189,10 @@ int mutt_protect (HEADER *msg, char *keylist)
     }
     if (traditional)
     {
-      mutt_message _("Invoking PGP...");
+      if (!isendwin ()) mutt_endwin _("Invoking PGP...");
       if (!(pbody = pgp_traditional_encryptsign (msg->content, flags, keylist)))
 	return -1;
-    
+
       msg->content = pbody;
       return 0;
     }
@@ -770,7 +770,7 @@ void mutt_signed_handler (BODY *a, STATE *s)
       state_attach_puts (_("[-- The following data is signed --]\n\n"), s);
 
 
-      safe_free((void **) &signatures);
+      FREE (&signatures);
     }
     else
       state_attach_puts (_("[-- Warning: Can't find any signatures. --]\n\n"), s);
