@@ -540,6 +540,7 @@ int mutt_addwch (wchar_t wc)
     return addstr (buf);
 }
 
+
 /*
  * This formats a string, a bit like
  * snprintf (dest, destlen, "%-*.*s", min_width, max_width, s),
@@ -694,3 +695,34 @@ void mutt_paddstr (int n, const char *s)
   while (n-- > 0)
     addch (' ');
 }
+
+/*
+ * mutt_strwidth is like mutt_strlen except that it returns the width
+ * refering to the number of characters cells.
+ */
+
+int mutt_strwidth (const char *s)
+{
+  wchar_t wc;
+  int w;
+  size_t k, n;
+  mbstate_t mbstate;
+
+  if (!s) return 0;
+
+  n = mutt_strlen (s);
+
+  memset (&mbstate, 0, sizeof (mbstate));
+  for (w=0; n && (k = mbrtowc (&wc, s, n, &mbstate)); s += k, n -= k)
+  {
+    if (k == (size_t)(-1) || k == (size_t)(-2))
+    {
+      k = (k == (size_t)(-1)) ? 1 : n;
+      wc = replacement_char ();
+    }
+    if (!IsWPrint (wc))
+      wc = '?';
+    w += wcwidth (wc);
+  }
+  return w;
+}
