@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -481,7 +481,7 @@ int mutt_index_menu (void)
 	if (!Context->path)
 	{
 	  /* fatal error occurred */
-	  safe_free ((void **) &Context);
+	  FREE (&Context);
 	  menu->redraw = REDRAW_FULL;
 	}
 
@@ -978,7 +978,7 @@ int mutt_index_menu (void)
 
 	/* check for a fatal error, or all messages deleted */
 	if (!Context->path)
-	  safe_free ((void **) &Context);
+	  FREE (&Context);
 
 	/* if we were in the pager, redisplay the message */
 	if (menu->menu == MENU_PAGER)
@@ -1038,7 +1038,7 @@ int mutt_index_menu (void)
 	    menu->redraw = REDRAW_INDEX | REDRAW_STATUS;
 	    break;
 	  }
-	  safe_free ((void **) &Context);
+	  FREE (&Context);
 	}
 
         mutt_sleep (0);
@@ -1109,7 +1109,7 @@ int mutt_index_menu (void)
 	  if (Context)
 	  {
 	    mx_fastclose_mailbox (Context);
-	    safe_free ((void **) &Context);
+	    FREE (&Context);
 	  }
 	  done = 1;
 	}
@@ -1267,15 +1267,18 @@ int mutt_index_menu (void)
       case OP_MAIN_NEXT_UNREAD:
       case OP_MAIN_PREV_NEW:
       case OP_MAIN_PREV_UNREAD:
+      case OP_MAIN_NEXT_NEW_THEN_UNREAD:
+      case OP_MAIN_PREV_NEW_THEN_UNREAD:
 
 	CHECK_MSGCOUNT;
         CHECK_VISIBLE;
+      next_unread_again:
 	i = menu->current;
 	menu->current = -1;
 	for (j = 0; j != Context->vcount; j++)
 	{
 #define CURHDRi Context->hdrs[Context->v2r[i]] 
-	  if (op == OP_MAIN_NEXT_NEW || op == OP_MAIN_NEXT_UNREAD)
+	  if (op == OP_MAIN_NEXT_NEW || op == OP_MAIN_NEXT_UNREAD || op == OP_MAIN_NEXT_NEW_THEN_UNREAD)
 	  {
 	    i++;
 	    if (i > Context->vcount - 1)
@@ -1302,7 +1305,8 @@ int mutt_index_menu (void)
 	      menu->current = i;
 	      break;
 	    }
-	    if ((op == OP_MAIN_NEXT_NEW || op == OP_MAIN_PREV_NEW) &&
+	    if ((op == OP_MAIN_NEXT_NEW || op == OP_MAIN_PREV_NEW || 
+		 op == OP_MAIN_NEXT_NEW_THEN_UNREAD || op == OP_MAIN_PREV_NEW_THEN_UNREAD) &&
 		UNREAD (CURHDRi) == 1)
 	    {
 	      menu->current = i;
@@ -1322,6 +1326,16 @@ int mutt_index_menu (void)
 	if (menu->current == -1)
 	{
 	  menu->current = menu->oldcurrent;
+	  if (op == OP_MAIN_NEXT_NEW_THEN_UNREAD) 
+	  {
+	    op = OP_MAIN_NEXT_UNREAD;
+	    goto next_unread_again;
+	  }
+	  if (op == OP_MAIN_PREV_NEW_THEN_UNREAD)
+	  {
+	    op = OP_MAIN_PREV_UNREAD;
+	    goto next_unread_again;
+	  }
 	  mutt_error ("%s%s.", (op == OP_MAIN_NEXT_NEW || op == OP_MAIN_PREV_NEW) ? _("No new messages") : _("No unread messages"),
 		      Context->pattern ? _(" in this limited view") : "");
 	}
@@ -1987,6 +2001,10 @@ int mutt_index_menu (void)
 	menu->redraw = REDRAW_FULL;
 	break;
 
+      case OP_WHAT_KEY:
+	mutt_what_key();
+	break;
+
       default:
 	if (menu->menu == MENU_MAIN)
 	  km_error_key (MENU_MAIN);
