@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -79,6 +79,9 @@ be_snarf_data (FILE *f, char **buf, int *bufmax, int *buflen, int offset,
       safe_realloc ((void **)&buf, sizeof (char *) * (*bufmax += 25));
     buf[(*buflen)++] = safe_strdup (tmp);
   }
+  if (buf && *bufmax == *buflen) { /* Do not smash memory past buf */
+    safe_realloc ((void **)&buf, sizeof (char *) * (++*bufmax));
+  }
   if (buf) buf[*buflen] = NULL;
   return (buf);
 }
