@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 2000 Edmund Grimley Evans <edmundo@rano.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
@@ -165,7 +165,7 @@ static void replace_part (ENTER_STATE *state, size_t from, char *buf)
   memcpy (state->wbuf + state->curpos, savebuf, savelen * sizeof (wchar_t));
   state->lastchar = state->curpos + savelen;
 
-  safe_free ((void **) &savebuf);
+  FREE (&savebuf);
 }
 
 /*
@@ -278,7 +278,7 @@ int _mutt_enter_string (char *buf, size_t buflen, int y, int x,
 
 	case OP_EDITOR_HISTORY_DOWN:
 	  state->curpos = state->lastchar;
-	  replace_part (state, 0, mutt_history_prev (hclass));
+	  replace_part (state, 0, mutt_history_next (hclass));
 	  redraw = M_REDRAW_INIT;
 	  break;
 
@@ -686,7 +686,7 @@ self_insert:
   
   bye:
   
-  safe_free ((void **) &tempbuf);
+  FREE (&tempbuf);
   return rv;
 }
 
@@ -694,8 +694,8 @@ void mutt_free_enter_state (ENTER_STATE **esp)
 {
   if (!esp) return;
   
-  safe_free ((void **) &(*esp)->wbuf);
-  safe_free ((void **) esp);
+  FREE (&(*esp)->wbuf);
+  FREE (esp);
 }
 
 /*
