@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -60,6 +60,7 @@ struct binding_t OpGeneric[] = {
   { "current-top",      OP_CURRENT_TOP,		NULL },
   { "current-middle",   OP_CURRENT_MIDDLE,	NULL },
   { "current-bottom",   OP_CURRENT_BOTTOM,	NULL },
+  { "what-key",		OP_WHAT_KEY,		NULL },
   { NULL,		0,			NULL }
 };
 
@@ -129,8 +130,10 @@ struct binding_t OpMain[] = {
   { "sync-mailbox",		OP_MAIN_SYNC_FOLDER,		"$" },
   { "display-address",		OP_DISPLAY_ADDRESS,		"@" },
   { "pipe-message",		OP_PIPE,			"|" },
-  { "next-new",			OP_MAIN_NEXT_NEW,		"\t" },
-  { "previous-new",		OP_MAIN_PREV_NEW,		"\033\t" },
+  { "next-new",			OP_MAIN_NEXT_NEW,		NULL },
+  { "next-new-then-unread",	OP_MAIN_NEXT_NEW_THEN_UNREAD,	"\t" },
+  { "previous-new",		OP_MAIN_PREV_NEW,		NULL },
+  { "previous-new-then-unread",	OP_MAIN_PREV_NEW_THEN_UNREAD,	"\033\t" },
   { "next-unread",		OP_MAIN_NEXT_UNREAD,		NULL },
   { "previous-unread",		OP_MAIN_PREV_UNREAD,		NULL },
   { "parent-message",		OP_MAIN_PARENT_MESSAGE,		"P" },
@@ -204,7 +207,9 @@ struct binding_t OpPager[] = {
   { "show-version",	OP_VERSION,			"V" },
   { "search-toggle",	OP_SEARCH_TOGGLE,		"\\" },
   { "display-address",	OP_DISPLAY_ADDRESS,		"@" },
-  { "next-new",		OP_MAIN_NEXT_NEW,		"\t" },
+  { "next-new",		OP_MAIN_NEXT_NEW,		NULL },
+  { "next-new-then-unread", 
+                        OP_MAIN_NEXT_NEW_THEN_UNREAD,   "\t" },
   { "pipe-message",	OP_PIPE,			"|" },
   { "help",		OP_HELP,			"?" },
   { "next-page",	OP_NEXT_PAGE,			" " },
@@ -221,6 +226,8 @@ struct binding_t OpPager[] = {
   { "jump",		OP_JUMP,			NULL },
   { "next-unread",	OP_MAIN_NEXT_UNREAD,		NULL },
   { "previous-new",	OP_MAIN_PREV_NEW,		NULL },
+  { "previous-new-then-unread",
+      			OP_MAIN_PREV_NEW_THEN_UNREAD,   NULL },
   { "previous-unread",	OP_MAIN_PREV_UNREAD,		NULL },
   { "half-up",		OP_HALF_UP,			NULL },
   { "half-down",	OP_HALF_DOWN,			NULL },
