@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 1998-2000 Werner Koch <werner.koch@guug.de>
- * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@does-not-exist.org>
  *
  *     This program is free software; you can redistribute it
  *     and/or modify it under the terms of the GNU General Public
@@ -44,7 +44,6 @@
 #include "mutt.h"
 #include "pgp.h"
 #include "charset.h"
-#include "iconv.h"
 
 /* for hexval */
 #include "mime.h"
@@ -91,7 +90,7 @@ static void fix_uid (char *uid)
   {
     int n = s - uid + 1; /* chars available in original buffer */
     char *buf;
-    const char *ib;
+    ICONV_CONST char *ib;
     char *ob;
     size_t ibl, obl;
 
@@ -108,7 +107,7 @@ static void fix_uid (char *uid)
       else if (ob-buf == n && (buf[n] = 0, strlen (buf) < n))
 	memcpy (uid, buf, n);
     }
-    safe_free ((void **) &buf);
+    FREE (&buf);
     iconv_close (cd);
   }
 }
