@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000,2002 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -26,6 +26,10 @@
 #include "pgp.h"
 #endif
 
+#ifdef HAVE_SMIME
+#include "smime.h"
+#endif
+
 
 
 #include <ctype.h>
@@ -342,7 +346,7 @@ hdr_format_str (char *dest,
 	  if (*cp == '%')
 	  {
 	    cp++;
-	    if (*cp == 'Z' && (op == 'd' || op == '{'))
+	    if ((*cp == 'Z' || *cp == 'z') && (op == 'd' || op == '{'))
 	    {
 	      if (len >= 5)
 	      {
@@ -415,8 +419,13 @@ hdr_format_str (char *dest,
       break;
 
     case 'E':
-      snprintf (fmt, sizeof (fmt), "%%%sd", prefix);
-      snprintf (dest, destlen, fmt, mutt_messages_in_thread(ctx, hdr, 0));
+      if (!optional)
+      {
+	snprintf (fmt, sizeof (fmt), "%%%sd", prefix);
+	snprintf (dest, destlen, fmt, mutt_messages_in_thread(ctx, hdr, 0));
+      }
+      else if (mutt_messages_in_thread(ctx, hdr, 0) <= 1)
+	optional = 0;
       break;
 
     case 'f':
@@ -445,11 +454,8 @@ hdr_format_str (char *dest,
 	snprintf (fmt, sizeof (fmt), "%%%sd", prefix);
 	snprintf (dest, destlen, fmt, (int) hdr->lines);
       }
-      else
-      {
-	if (hdr->lines > 0)
-	  optional = 0;
-      }
+      else if (hdr->lines <= 0)
+        optional = 0;
       break;
 
     case 'L':
@@ -487,7 +493,7 @@ hdr_format_str (char *dest,
       }
       else
       {
-	if (hdr->score > 0)
+	if (hdr->score == 0)
 	  optional = 0;
       }
       break;
@@ -618,15 +624,17 @@ hdr_format_str (char *dest,
     
       ch = ' ';
 
-#ifdef HAVE_PGP
-      if (hdr->pgp & PGPGOODSIGN)
+#if defined(HAVE_PGP) || defined(HAVE_SMIME)
+      if (hdr->security & GOODSIGN)
         ch = 'S';
-      else if (hdr->pgp & PGPENCRYPT)
+      else if (hdr->security & ENCRYPT)
       	ch = 'P';
-      else if (hdr->pgp & PGPSIGN)
+      else if (hdr->security & SIGN)
         ch = 's';
-      else if (hdr->pgp & PGPKEY)
+#ifdef HAVE_PGP
+      else if (hdr->security & PGPKEY)
         ch = 'K';
+#endif
 #endif
 
       snprintf (buf2, sizeof (buf2),
