@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-8 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 1996-9 Brandon Long <blong@fiction.net>
- * Copyright (C) 1999-2001 Brendan Cully <brendan@kublai.com>
+ * Copyright (C) 1999-2002 Brendan Cully <brendan@kublai.com>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -378,7 +378,7 @@ int imap_open_connection (IMAP_DATA* idata)
   if (imap_cmd_step (idata) != IMAP_CMD_CONTINUE)
     goto bail;
 
-  if (mutt_strncmp ("* OK", idata->cmd.buf, 4) == 0)
+  if (ascii_strncasecmp ("* OK", idata->cmd.buf, 4) == 0)
   {
     /* TODO: Parse new tagged CAPABILITY data (* OK [CAPABILITY...]) */
     if (imap_check_capabilities (idata))
@@ -419,7 +419,7 @@ int imap_open_connection (IMAP_DATA* idata)
       dprint (2, (debugfile, "Communication encrypted at %d bits\n",
 	idata->conn->ssf));
   }
-  else if (mutt_strncmp ("* PREAUTH", idata->cmd.buf, 9) == 0)
+  else if (ascii_strncasecmp ("* PREAUTH", idata->cmd.buf, 9) == 0)
   {
     if (imap_check_capabilities (idata) != 0)
       goto bail;
@@ -560,17 +560,6 @@ int imap_open_mailbox (CONTEXT* ctx)
     if ((rc = imap_cmd_step (idata)) != IMAP_CMD_CONTINUE)
       break;
 
-    pc = idata->cmd.buf + 2;
-    pc = imap_next_word (pc);
-    if (!ascii_strncasecmp ("EXISTS", pc, 6))
-    {
-      /* imap_handle_untagged will have picked up the EXISTS message and
-       * set the NEW_MAIL flag. We clear it here. */
-      idata->reopen &= ~IMAP_NEWMAIL_PENDING;
-      count = idata->newMailCount;
-      idata->newMailCount = 0;
-    }
-
     pc = idata->cmd.buf + 2;
 
     /* Obtain list of available flags here, may be overridden by a
@@ -596,6 +585,15 @@ int imap_open_mailbox (CONTEXT* ctx)
       if ((pc = imap_get_flags (&(idata->flags), pc)) == NULL)
 	goto fail;
     }
+    else
+    {
+      pc = imap_next_word (pc);
+      if (!ascii_strncasecmp ("EXISTS", pc, 6))
+      {
+	count = idata->newMailCount;
+	idata->newMailCount = 0;
+      }
+    }
   }
   while (rc == IMAP_CMD_CONTINUE);
 
@@ -613,7 +611,7 @@ int imap_open_mailbox (CONTEXT* ctx)
     goto fail;
 
   /* check for READ-ONLY notification */
-  if (!strncmp (imap_get_qualifier (idata->cmd.buf), "[READ-ONLY]", 11))
+  if (!ascii_strncasecmp (imap_get_qualifier (idata->cmd.buf), "[READ-ONLY]", 11))
   {
     dprint (2, (debugfile, "Mailbox is read-only.\n"));
     ctx->readonly = 1;
@@ -871,7 +869,7 @@ int imap_make_msg_set (IMAP_DATA* idata, BUFFER* buf, int flag, int changed)
     }
   }
 
-  safe_free ((void**) &hdrs);
+  FREE (&hdrs);
 
   return count;
 }
@@ -1079,6 +1077,7 @@ void imap_close_mailbox (CONTEXT* ctx)
     idata->reopen &= IMAP_REOPEN_ALLOW;
     idata->state = IMAP_AUTHENTICATED;
     FREE (&(idata->mailbox));
+    mutt_free_list (&idata->flags);
   }
 
   /* free IMAP part of headers */
@@ -1090,7 +1089,7 @@ void imap_close_mailbox (CONTEXT* ctx)
     if (idata->cache[i].path)
     {
       unlink (idata->cache[i].path);
-      safe_free ((void **) &idata->cache[i].path);
+      FREE (&idata->cache[i].path);
     }
   }
 }
@@ -1183,7 +1182,7 @@ int imap_mailbox_check (char* path, int new)
    */
 
   if (mutt_strcmp (mbox_unquoted, idata->mailbox) == 0
-      || (mutt_strcasecmp (mbox_unquoted, "INBOX") == 0
+      || (ascii_strcasecmp (mbox_unquoted, "INBOX") == 0
 	  && mutt_strcasecmp (mbox_unquoted, idata->mailbox) == 0))
   {
     strfcpy (buf, "NOOP", sizeof (buf));
@@ -1289,7 +1288,7 @@ int imap_parse_list_response(IMAP_DATA* idata, char **name, int *noselect,
       return 0;
     s = imap_next_word (s); /* delim */
     /* Reset the delimiter, this can change */
-    if (strncmp (s, "NIL", 3))
+    if (ascii_strncasecmp (s, "NIL", 3))
     {
       if (s && s[0] == '\"' && s[1] && s[2] == '\"')
 	*delim = s[1];
@@ -1434,7 +1433,7 @@ int imap_complete(char* dest, size_t dlen, char* path) {
       completions++;
     }
   }
-  while (mutt_strncmp(idata->cmd.seq, idata->cmd.buf, SEQLEN));
+  while (ascii_strncmp(idata->cmd.seq, idata->cmd.buf, SEQLEN));
 
   if (completions)
   {
