@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000,2002 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000,2002 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -120,6 +120,19 @@ static int parse_fkey(char *s)
     return n;
 }
 
+/*
+ * This function parses the string <NNN> and uses the octal value as the key
+ * to bind.
+ */
+static int parse_keycode (const char *s)
+{
+  if (isdigit (s[1]) && isdigit (s[2]) && isdigit (s[3]) && s[4] == '>')
+  {
+    return (s[3] - '0') + (s[2] - '0') * 8 + (s[1] - '0') * 64;
+  }
+  return -1;
+}
+
 static int parsekeys (char *str, keycode_t *d, int max)
 {
   int n, len = max;
@@ -147,6 +160,11 @@ static int parsekeys (char *str, keycode_t *d, int max)
 	s = t;
 	*d = KEY_F (n);
       }
+      else if ((n = parse_keycode(s)) > 0)
+      {
+	s = t;
+	*d = n;
+      }
       
       *t = c;
     }
@@ -892,3 +910,25 @@ int mutt_parse_exec (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
 
   return 0;
 }
+
+/*
+ * prompts the user to enter a keystroke, and displays the octal value back
+ * to the user.
+ */
+void mutt_what_key (void)
+{
+  int ch;
+
+  mvprintw(LINES-1,0,"Enter keys (^G to abort): ");
+  do {
+    ch = getch();
+    if (ch != ERR && ch != ctrl ('G'))
+    {
+      mutt_message("Char = %s, Octal = %o, Decimal = %d",
+	       km_keyname(ch), ch, ch);
+    }
+  }
+  while (ch != ERR && ch != ctrl ('G'));
+
+  mutt_flushinp();
+}
