@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000,2 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */ 
 
 #ifndef KEYMAP_H
@@ -46,6 +46,7 @@ int km_expand_key (char *, size_t, struct keymap_t *);
 struct keymap_t *km_find_func (int, int);
 void km_init (void);
 void km_error_key (int);
+void mutt_what_key (void);
 
 enum
 {
@@ -65,6 +66,10 @@ enum
   MENU_PGP,
 #endif
 
+#ifdef HAVE_SMIME
+  MENU_SMIME,
+#endif
+
 #ifdef MIXMASTER
   MENU_MIX,
 #endif
@@ -100,11 +105,16 @@ extern struct binding_t OpCompose[];
 extern struct binding_t OpBrowser[];
 extern struct binding_t OpEditor[];
 extern struct binding_t OpQuery[];
+extern struct binding_t OpAlias[];
 
 #ifdef HAVE_PGP
 extern struct binding_t OpPgp[];
 #endif /* HAVE_PGP */
 
+#ifdef HAVE_SMIME
+extern struct binding_t OpSmime[];
+#endif /* HAVE_SMIME */
+
 #ifdef MIXMASTER
 extern struct binding_t OpMix[];
 #endif
