@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@does-not-exist.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -517,10 +517,10 @@ static void char_to_escape (char *dest, unsigned int c)
 {
   switch (c)
   {
-    case '\r': strcpy (dest, "\\r"); break;
-    case '\n': strcpy (dest, "\\n"); break;
-    case '\t': strcpy (dest, "\\t"); break;
-    case '\f': strcpy (dest, "\\f"); break;
+    case '\r': strcpy (dest, "\\r"); break;	/* __STRCPY_CHECKED__ */
+    case '\n': strcpy (dest, "\\n"); break;	/* __STRCPY_CHECKED__ */
+    case '\t': strcpy (dest, "\\t"); break;	/* __STRCPY_CHECKED__ */
+    case '\f': strcpy (dest, "\\f"); break;	/* __STRCPY_CHECKED__ */
     default: sprintf (dest, "\\%03o", c); break;
   }
 }
