@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -683,17 +683,17 @@ void mutt_menuDestroy (MUTTMENU **p)
 {
   int i;
 
-  safe_free ((void **) &(*p)->searchBuf);
+  FREE (&(*p)->searchBuf);
 
   if ((*p)->dialog) 
   {
     for (i=0; i < (*p)->max; i++)
-      safe_free ((void **) &(*p)->dialog[i]);
+      FREE (&(*p)->dialog[i]);
 
-    safe_free ((void **) (*p)->dialog);
+    FREE ((*p)->dialog);
   }
 
-  safe_free ((void **) p);
+  FREE (p);
 }
 
 #define M_SEARCH_UP   1
@@ -1014,6 +1014,10 @@ int mutt_menuLoop (MUTTMENU *menu)
 	MAYBE_REDRAW (menu->redraw);
 	break;
 
+      case OP_WHAT_KEY:
+	mutt_what_key ();
+	break;
+
       case OP_REDRAW:
 	clearok (stdscr, TRUE);
 	menu->redraw = REDRAW_FULL;
