@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1998 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1998 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 1999-2001 Brendan Cully <brendan@kublai.com>
  * Copyright (C) 1999-2000 Tommi Komulainen <Tommi.Komulainen@iki.fi>
  * 
@@ -258,7 +258,7 @@ CONNECTION* mutt_conn_find (const CONNECTION* start, const ACCOUNT* account)
 #else
     mutt_error _("SSL is unavailable.");
     mutt_sleep (2);
-    FREE (&conn);
+    mutt_socket_free (conn);
 
     return NULL;
 #endif
