@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@does-not-exist.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -28,12 +28,16 @@
 
 #ifdef USE_IMAP
 #include "imap.h"
-#endif
+ #endif
 
 #ifdef HAVE_PGP
 #include "pgp.h"
 #endif
 
+#ifdef HAVE_SMIME
+#include "smime.h"
+#endif
+
 #include <string.h>
 #include <ctype.h>
 #include <unistd.h>
@@ -134,7 +138,7 @@ int mutt_copy_body (FILE *fp, BODY **tgt, BODY *src)
   b->use_disp = use_disp;
   b->unlink = 1;
 
-  if (mutt_is_text_type (b->type, b->subtype))
+  if (mutt_is_text_part (b))
     b->noconv = 1;
 
   b->xtype = safe_strdup (b->xtype);
@@ -178,13 +182,19 @@ void mutt_free_body (BODY **p)
     if (b->parameter)
       mutt_free_parameter (&b->parameter);
     if (b->unlink && b->filename)
+    {
+      dprint (1, (debugfile, "mutt_free_body: Unlinking %s.\n", b->filename));
       unlink (b->filename);
-    safe_free ((void **) &b->filename);
-    safe_free ((void **) &b->content);
-    safe_free ((void **) &b->xtype);
-    safe_free ((void **) &b->subtype);
-    safe_free ((void **) &b->description);
-    safe_free ((void **) &b->form_name);
+    }
+    else if (b->filename) 
+      dprint (1, (debugfile, "mutt_free_body: Not unlinking %s.\n", b->filename));
+
+    FREE (&b->filename);
+    FREE (&b->content);
+    FREE (&b->xtype);
+    FREE (&b->subtype);
+    FREE (&b->description);
+    FREE (&b->form_name);
 
     if (b->hdr)
     {
@@ -196,7 +206,7 @@ void mutt_free_body (BODY **p)
     if (b->parts)
       mutt_free_body (&b->parts);
 
-    safe_free ((void **) &b);
+    FREE (&b);
   }
 
   *p = 0;
@@ -209,11 +219,11 @@ void mutt_free_parameter (PARAMETER **p)
 
   while (t)
   {
-    safe_free ((void **) &t->attribute);
-    safe_free ((void **) &t->value);
+    FREE (&t->attribute);
+    FREE (&t->value);
     o = t;
     t = t->next;
-    safe_free ((void **) &o);
+    FREE (&o);
   }
   *p = 0;
 }
@@ -246,8 +256,8 @@ void mutt_free_list (LIST **list)
   {
     p = *list;
     *list = (*list)->next;
-    safe_free ((void **) &p->data);
-    safe_free ((void **) &p);
+    FREE (&p->data);
+    FREE (&p);
   }
 }
 
@@ -265,15 +275,16 @@ void mutt_free_header (HEADER **h)
   if(!h || !*h) return;
   mutt_free_envelope (&(*h)->env);
   mutt_free_body (&(*h)->content);
-  safe_free ((void **) &(*h)->tree);
-  safe_free ((void **) &(*h)->path);
+  FREE (&(*h)->maildir_flags);
+  FREE (&(*h)->tree);
+  FREE (&(*h)->path);
 #ifdef MIXMASTER
   mutt_free_list (&(*h)->chain);
 #endif
 #if defined USE_POP || defined USE_IMAP
-  safe_free ((void**) &(*h)->data);
+  FREE (&(*h)->data);
 #endif
-  safe_free ((void **) h);
+  FREE (h);
 }
 
 /* returns true if the header contained in "s" is in list "t" */
@@ -594,9 +605,14 @@ int mutt_needs_mailcap (BODY *m)
     case TYPEAPPLICATION:
       if(mutt_is_application_pgp(m))
 	return 0;
-      break;
 #endif /* HAVE_PGP */
 
+#ifdef HAVE_SMIME
+      if(mutt_is_application_smime(m))
+	return 0;
+      break;
+#endif /* HAVE_SMIME */
+
 
     case TYPEMULTIPART:
     case TYPEMESSAGE:
@@ -607,8 +623,16 @@ int mutt_needs_mailcap (BODY *m)
   return 1;
 }
 
-int mutt_is_text_type (int t, char *s)
+int mutt_is_text_part (BODY *b)
 {
+  int t = b->type;
+  char *s = b->subtype;
+  
+  
+#ifdef HAVE_PGP
+  if (mutt_is_application_pgp (b))
+    return 0;
+#endif
   if (t == TYPETEXT)
     return 1;
 
@@ -644,19 +668,20 @@ void mutt_free_envelope (ENVELOPE **p)
   rfc822_free_address (&(*p)->from);
   rfc822_free_address (&(*p)->reply_to);
   rfc822_free_address (&(*p)->mail_followup_to);
-  safe_free ((void **) &(*p)->subject);
-  safe_free ((void **) &(*p)->message_id);
-  safe_free ((void **) &(*p)->supersedes);
-  safe_free ((void **) &(*p)->date);
+  FREE (&(*p)->subject);
+  FREE (&(*p)->message_id);
+  FREE (&(*p)->supersedes);
+  FREE (&(*p)->date);
   mutt_free_list (&(*p)->references);
   mutt_free_list (&(*p)->in_reply_to);
   mutt_free_list (&(*p)->userhdrs);
-  safe_free ((void **) p);
+  FREE (p);
 }
 
-void mutt_mktemp (char *s)
+void _mutt_mktemp (char *s, const char *src, int line)
 {
   snprintf (s, _POSIX_PATH_MAX, "%s/mutt-%s-%d-%d", NONULL (Tempdir), NONULL(Hostname), (int) getpid (), Counter++);
+  dprint (1, (debugfile, "%s:%d: mutt_mktemp returns \"%s\".\n", src, line, s));
   unlink (s);
 }
 
@@ -668,9 +693,9 @@ void mutt_free_alias (ALIAS **p)
   {
     t = *p;
     *p = (*p)->next;
-    safe_free ((void **) &t->name);
+    FREE (&t->name);
     rfc822_free_address (&t->addr);
-    safe_free ((void **) &t);
+    FREE (&t);
   }
 }
 
@@ -1117,7 +1142,7 @@ FILE *mutt_open_read (const char *path, pid_t *thepid)
     s[len - 1] = 0;
     mutt_endwin (NULL);
     *thepid = mutt_create_filter (s, NULL, &f, NULL);
-    safe_free ((void **) &s);
+    FREE (&s);
   }
   else
   {
@@ -1189,29 +1214,29 @@ int mutt_save_confirm (const char *s, struct stat *st)
   return (ret);
 }
 
-void state_prefix_putc(char c, STATE *s)
+void state_prefix_putc (char c, STATE *s)
 {
   if (s->flags & M_PENDINGPREFIX)
   {
-    state_reset_prefix(s);
+    state_reset_prefix (s);
     if (s->prefix)
-      state_puts(s->prefix, s);
+      state_puts (s->prefix, s);
   }
 
-  state_putc(c, s);
+  state_putc (c, s);
 
-  if(c == '\n')
-    state_set_prefix(s);
+  if (c == '\n')
+    state_set_prefix (s);
 }
 
-int state_printf(STATE *s, const char *fmt, ...)
+int state_printf (STATE *s, const char *fmt, ...)
 {
   int rv;
   va_list ap;
 
   va_start (ap, fmt);
-  rv = vfprintf(s->fpout, fmt, ap);
-  va_end(ap);
+  rv = vfprintf (s->fpout, fmt, ap);
+  va_end (ap);
   
   return rv;
 }
