@@ -384,8 +384,8 @@ cleanup_quote (struct q_class_t **QuoteList)
       cleanup_quote (&((*QuoteList)->down));
     ptr = (*QuoteList)->next;
     if ((*QuoteList)->prefix)
-      safe_free ((void **) &(*QuoteList)->prefix);
-    safe_free ((void **) QuoteList);
+      FREE (&(*QuoteList)->prefix);
+    FREE (QuoteList);
     *QuoteList = ptr;
   }
 
@@ -1613,7 +1613,7 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
 	lines = Resize->line;
 	redraw |= REDRAW_SIGWINCH;
 
-	safe_free ((void **) &Resize);
+	FREE (&Resize);
       }
 #endif
 
@@ -1796,7 +1796,7 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
 	  safe_realloc ((void **)&(lineInfo[i].syntax),
 			sizeof (struct syntax_t));
 	  if (SearchCompiled && lineInfo[i].search)
-	      safe_free ((void **) &(lineInfo[i].search));
+	      FREE (&(lineInfo[i].search));
 	}
 
 	lastLine = 0;
@@ -1954,13 +1954,13 @@ search_next:
 
       case OP_SEARCH:
       case OP_SEARCH_REVERSE:
-	buffer[0] = 0;
+        strfcpy (buffer, searchbuf, sizeof (buffer));
 	if (mutt_get_field ((SearchBack ? _("Reverse search: ") :
 			  _("Search: ")), buffer, sizeof (buffer),
 			  M_CLEAR) != 0)
 	  break;
 
-	if (!buffer[0])
+	if (!strcmp (buffer, searchbuf))
 	{
 	  if (SearchCompiled)
 	  {
@@ -1972,13 +1972,11 @@ search_next:
 
 	    goto search_next;
 	  }
-	  /*
-	   * preserve old behavior of doing nothing if there is no last
-	   * used pattern.
-	   */
-	  break;
 	}
-
+      
+        if (!buffer[0])
+	  break;
+      
 	strfcpy (searchbuf, buffer, sizeof (searchbuf));
 
 	/* leave SearchBack alone if ch == OP_SEARCH_NEXT */
@@ -1993,7 +1991,7 @@ search_next:
 	  for (i = 0; i < lastLine; i++)
 	  {
 	    if (lineInfo[i].search)
-	      safe_free ((void **) &(lineInfo[i].search));
+	      FREE (&(lineInfo[i].search));
 	    lineInfo[i].search_cnt = -1;
 	  }
 	}
@@ -2007,7 +2005,7 @@ search_next:
 	  {
 	    /* cleanup */
 	    if (lineInfo[i].search)
-	      safe_free ((void **) &(lineInfo[i].search));
+	      FREE (&(lineInfo[i].search));
 	    lineInfo[i].search_cnt = -1;
 	  }
 	  SearchFlag = 0;
@@ -2289,7 +2287,7 @@ search_next:
 
 	    safe_realloc ((void **)&(lineInfo[i].syntax), sizeof (struct syntax_t));
 	    if (SearchCompiled && lineInfo[i].search)
-		safe_free ((void **) &(lineInfo[i].search));
+		FREE (&(lineInfo[i].search));
 	  }
 
 	  if (SearchCompiled)
@@ -2596,16 +2594,16 @@ search_next:
   
   for (i = 0; i < maxLine ; i++)
   {
-    safe_free ((void **) &(lineInfo[i].syntax));
+    FREE (&(lineInfo[i].syntax));
     if (SearchCompiled && lineInfo[i].search)
-      safe_free ((void **) &(lineInfo[i].search));
+      FREE (&(lineInfo[i].search));
   }
   if (SearchCompiled)
   {
     regfree (&SearchRE);
     SearchCompiled = 0;
   }
-  safe_free ((void **) &lineInfo);
+  FREE (&lineInfo);
   if (index)
     mutt_menuDestroy(&index);
   return (rc != -1 ? rc : 0);
