@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -28,6 +28,10 @@
 #include "pgp.h"
 #endif /* HAVE_PGP */
 
+#ifdef HAVE_SMIME
+#include "smime.h"
+#endif /* HAVE_SMIME */
+
 
 
 #include <string.h>
@@ -90,23 +94,65 @@ static char *read_rfc822_line (FILE *f, char *line, size_t *linelen)
   /* not reached */
 }
 
-static LIST *mutt_parse_references (char *s)
+static LIST *mutt_parse_references (char *s, int in_reply_to)
 {
   LIST *t, *lst = NULL;
+  int m, n = 0;
+  char *o = NULL, *new, *at;
 
-  while ((s = strtok (s, " \t")) != NULL)
+  while ((s = strtok (s, " \t;")) != NULL)
   {
     /*
      * some mail clients add other garbage besides message-ids, so do a quick
      * check to make sure this looks like a valid message-id
+     * some idiotic clients also break their message-ids between lines, deal
+     * with that too (give up if it's more than two lines, though)
      */
+    t = NULL;
+    new = NULL;
+
     if (*s == '<')
     {
-      t = (LIST *)safe_malloc (sizeof (LIST));
-      t->data = safe_strdup (s);
-      t->next = lst;
-      lst = t;
+      n = strlen (s);
+      if (s[n-1] != '>')
+      {
+	o = s;
+	s = NULL;
+	continue;
+      }
+
+      new = safe_strdup (s);
     }
+    else if (o)
+    {
+      m = strlen (s);
+      if (s[m - 1] == '>')
+      {
+	new = safe_malloc (sizeof (char) * (n + m + 1));
+	strcpy (new, o);	/* __STRCPY_CHECKED__ */
+	strcpy (new + n, s);	/* __STRCPY_CHECKED__ */
+      }
+    }
+    if (new)
+    {
+      /* make sure that this really does look like a message-id.
+       * it should have exactly one @, and if we're looking at
+       * an in-reply-to header, make sure that the part before
+       * the @ has more than eight characters or it's probably
+       * an email address
+       */
+      if (!(at = strchr (new, '@')) || strchr (at + 1, '@')
+	  || (in_reply_to && at - new <= 8))
+	FREE (&new);
+      else
+      {
+	t = (LIST *) safe_malloc (sizeof (LIST));
+	t->data = new;
+	t->next = lst;
+	lst = t;
+      }
+    }
+    o = NULL;
     s = NULL;
   }
 
@@ -198,7 +244,9 @@ static PARAMETER *parse_parameters (const char *s)
 
       new->value = safe_strdup (buffer);
 
-      dprint (2, (debugfile, "parse_parameter: `%s' = `%s'\n", new->attribute, new->value));
+      dprint (2, (debugfile, "parse_parameter: `%s' = `%s'\n",
+		  new->attribute ? new->attribute : "",
+		  new->value ? new->value : ""));
       
       /* Add this parameter to the list */
       if (head)
@@ -266,7 +314,7 @@ void mutt_parse_content_type (char *s, BODY *ct)
   char *pc;
   char *subtype;
 
-  safe_free((void **)&ct->subtype);
+  FREE (&ct->subtype);
   mutt_free_parameter(&ct->parameter);
 
   /* First extract any existing parameters */
@@ -892,11 +940,9 @@ void mutt_parse_mime_message (CONTEXT *ctx, HEADER *cur)
   {
     mutt_parse_part (msg->fp, cur->content);
 
-
-#ifdef HAVE_PGP
-    cur->pgp = pgp_query (cur->content);
-#endif /* HAVE_PGP */
-
+#if defined(HAVE_PGP) ||  defined(HAVE_SMIME)
+    cur->security = crypt_query (cur->content);
+#endif
 
     mx_close_message (&msg);
   }
@@ -1009,7 +1055,7 @@ int mutt_parse_rfc822_line (ENVELOPE *e, HEADER *hdr, char *line, char *p, short
     if (!ascii_strcasecmp (line+1, "n-reply-to"))
     {
       mutt_free_list (&e->in_reply_to);
-      e->in_reply_to = mutt_parse_references (p);
+      e->in_reply_to = mutt_parse_references (p, 1);
       matched = 1;
     }
     break;
@@ -1019,6 +1065,14 @@ int mutt_parse_rfc822_line (ENVELOPE *e, HEADER *hdr, char *line, char *p, short
     {
       if (hdr)
 	hdr->lines = atoi (p);
+
+      /* 
+       * HACK - mutt has, for a very short time, produced negative
+       * Lines header values.  Ignore them. 
+       */
+      if (hdr->lines < 0)
+	hdr->lines = 0;
+
       matched = 1;
     }
     break;
@@ -1033,7 +1087,7 @@ int mutt_parse_rfc822_line (ENVELOPE *e, HEADER *hdr, char *line, char *p, short
     else if (!ascii_strcasecmp (line + 1, "essage-id"))
     {
       /* We add a new "Message-Id:" when building a message */
-      safe_free ((void **) &e->message_id);
+      FREE (&e->message_id);
       e->message_id = extract_message_id (p);
       matched = 1;
     }
@@ -1058,7 +1112,7 @@ int mutt_parse_rfc822_line (ENVELOPE *e, HEADER *hdr, char *line, char *p, short
     if (!ascii_strcasecmp (line + 1, "eferences"))
     {
       mutt_free_list (&e->references);
-      e->references = mutt_parse_references (p);
+      e->references = mutt_parse_references (p, 0);
       matched = 1;
     }
     else if (!ascii_strcasecmp (line + 1, "eply-to"))
@@ -1107,7 +1161,6 @@ int mutt_parse_rfc822_line (ENVELOPE *e, HEADER *hdr, char *line, char *p, short
 	    hdr->replied = 1;
 	    break;
 	    case 'O':
-	    if (option (OPTMARKOLD))
 	      hdr->old = 1;
 	    break;
 	    case 'R':
