@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>, and others
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>, and others
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -35,6 +35,10 @@
 #include "pgp.h"
 #endif
 
+#ifdef HAVE_SMIME
+#include "smime.h"
+#endif
+
 
 
 static int eat_regexp (pattern_t *pat, BUFFER *, BUFFER *);
@@ -61,9 +65,9 @@ Flags[] =
   { 'E', M_EXPIRED,		0,		NULL },
   { 'f', M_FROM,		0,		eat_regexp },
   { 'F', M_FLAG,		0,		NULL },
-#ifdef HAVE_PGP
-  { 'g', M_PGP_SIGN, 		0, 		NULL },
-  { 'G', M_PGP_ENCRYPT, 	0, 		NULL },
+#if defined (HAVE_PGP) || defined (HAVE_SMIME)
+  { 'g', M_CRYPT_SIGN, 		0, 		NULL },
+  { 'G', M_CRYPT_ENCRYPT, 	0, 		NULL },
 #endif
   { 'h', M_HEADER,		M_FULL_MSG,	eat_regexp },
   { 'i', M_ID,			0,		eat_regexp },
@@ -87,9 +91,13 @@ Flags[] =
   { 't', M_TO,			0,		eat_regexp },
   { 'U', M_UNREAD,		0,		NULL },
   { 'v', M_COLLAPSED,		0,		NULL },
+#if defined (HAVE_PGP) || defined (HAVE_SMIME)
+  { 'V', M_CRYPT_VERIFIED,      0,              NULL },
+#endif
   { 'x', M_REFERENCE,		0,		eat_regexp },
   { 'y', M_XLABEL,		0,		eat_regexp },
   { 'z', M_SIZE,		0,		eat_range },
+  { '=', M_DUPLICATED,		0,		NULL },
   { 0 }
 };
 
@@ -172,8 +180,8 @@ msg_search (CONTEXT *ctx, regex_t *rx, char *buf, size_t blen, int op, int msgno
 
 
 
-#ifdef HAVE_PGP
-	if (h->pgp & PGPENCRYPT && !pgp_valid_passphrase())
+#if defined(HAVE_PGP) || defined(HAVE_SMIME)
+	if (h->security & ENCRYPT && !crypt_valid_passphrase(h->security))
 	{
 	  mx_close_message (&msg);
 	  if (fp)
@@ -258,7 +266,7 @@ int eat_regexp (pattern_t *pat, BUFFER *s, BUFFER *err)
   {
     regerror (r, pat->rx, err->data, err->dsize);
     regfree (pat->rx);
-    safe_free ((void **) &pat->rx);
+    FREE (&pat->rx);
     return (-1);
   }
   return 0;
@@ -700,11 +708,11 @@ void mutt_pattern_free (pattern_t **pat)
     if (tmp->rx)
     {
       regfree (tmp->rx);
-      safe_free ((void **) &tmp->rx);
+      FREE (&tmp->rx);
     }
     if (tmp->child)
       mutt_pattern_free (&tmp->child);
-    safe_free ((void **) &tmp);
+    FREE (&tmp);
   }
 }
 
@@ -1030,7 +1038,7 @@ mutt_pattern_exec (struct pattern_t *pat, pattern_exec_flag flags, CONTEXT *ctx,
 					pat->alladdr, 4, h->env->from,
 					h->env->sender, h->env->to, h->env->cc));
     case M_RECIPIENT:
-      return (pat->not ^ match_adrlist (pat->rx, flags & M_MATCH_FULL_ADDRESS,
+           return (pat->not ^ match_adrlist (pat->rx, flags & M_MATCH_FULL_ADDRESS,
 					pat->alladdr, 2, h->env->to, h->env->cc));
     case M_LIST:
       return (pat->not ^ mutt_is_list_recipient (pat->alladdr, h->env->to, h->env->cc));
@@ -1040,16 +1048,22 @@ mutt_pattern_exec (struct pattern_t *pat, pattern_exec_flag flags, CONTEXT *ctx,
       return (pat->not ^ match_user (pat->alladdr, h->env->from, NULL));
     case M_COLLAPSED:
       return (pat->not ^ (h->collapsed && h->num_hidden > 1));
+#if defined (HAVE_PGP) || defined (HAVE_SMIME)
+   case M_CRYPT_SIGN:
+     return (pat->not ^ ((h->security & SIGN) ? 1 : 0));
+   case M_CRYPT_VERIFIED:
+     return (pat->not ^ ((h->security & GOODSIGN) ? 1 : 0));
+   case M_CRYPT_ENCRYPT:
+     return (pat->not ^ ((h->security & ENCRYPT) ? 1 : 0));
+#endif
 #ifdef HAVE_PGP
-   case M_PGP_SIGN:
-     return (pat->not ^ (h->pgp & PGPSIGN));
-   case M_PGP_ENCRYPT:
-     return (pat->not ^ (h->pgp & PGPENCRYPT));
    case M_PGP_KEY:
-     return (pat->not ^ (h->pgp & PGPKEY));
+     return (pat->not ^ ((h->security & APPLICATION_PGP) && (h->security & PGPKEY)));
 #endif
     case M_XLABEL:
       return (pat->not ^ (h->env->x_label && regexec (pat->rx, h->env->x_label, 0, NULL, 0) == 0));
+    case M_DUPLICATED:
+      return (pat->not ^ (h->thread && h->thread->duplicate_thread));
   }
   mutt_error (_("error: unknown op %d (report this error)."), pat->op);
   return (-1);
@@ -1060,7 +1074,7 @@ static void quote_simple(char *tmp, size_t len, const char *p)
   int i = 0;
   
   tmp[i++] = '"';
-  while (*p && i < len - 2)
+  while (*p && i < len - 3)
   {
     if (*p == '\\' || *p == '"')
       tmp[i++] = '\\';
@@ -1191,7 +1205,7 @@ int mutt_pattern_func (int op, char *prompt)
 
   if (op == M_LIMIT)
   {
-    safe_free ((void **) &Context->pattern);
+    FREE (&Context->pattern);
     if (Context->limit_pattern) 
       mutt_pattern_free (&Context->limit_pattern);
     if (!Context->vcount)
@@ -1231,7 +1245,7 @@ int mutt_search_command (int cur, int op)
   {
     strfcpy (buf, LastSearch, sizeof (buf));
     if (mutt_get_field ((op == OP_SEARCH) ? _("Search for: ") :
-		      "Reverse search for: ", buf, sizeof (buf),
+		      _("Reverse search for: "), buf, sizeof (buf),
 		      M_CLEAR | M_PATTERN) != 0 || !buf[0])
       return (-1);
 
