@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1996,1997 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (c) 1998,1999 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1996,1997 Michael R. Elkins <me@mutt.org>
+ * Copyright (c) 1998,1999 Thomas Roessler <roessler@does-not-exist.org>
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -123,7 +123,7 @@ static int pgp_copy_checksig (FILE *fpin, FILE *fpout)
       fputs (line, fpout);
       fputc ('\n', fpout);
     }
-    safe_free ((void **) &line);
+    FREE (&line);
   }
   else
   {
@@ -700,7 +700,7 @@ void pgp_extract_keys_from_attachment_list (FILE *fp, int tag, BODY *top)
 {
   if(!fp)
   {
-    mutt_error _("Internal error. Inform <roessler@guug.de>.");
+    mutt_error _("Internal error. Inform <roessler@does-not-exist.org>.");
     return;
   }
 
@@ -1029,6 +1029,20 @@ BODY *pgp_sign_message (BODY *a)
   return (a);
 }
 
+static short is_numerical_keyid (const char *s)
+{
+  /* or should we require the "0x"? */
+  if (strncmp (s, "0x", 2) == 0)
+    s += 2;
+  if (strlen (s) % 8)
+    return 0;
+  while (*s)
+    if (strchr ("0123456789ABCDEFabcdef", *s++) == NULL)
+      return 0;
+  
+  return 1;
+}
+
 /* This routine attempts to find the keyids of the recipients of a message.
  * It returns NULL if any of the keys can not be found.
  */
@@ -1078,6 +1092,13 @@ char *pgp_findKeys (ADDRESS *to, ADDRESS *cc, ADDRESS *bcc)
       snprintf (buf, sizeof (buf), _("Use keyID = \"%s\" for %s?"), keyID, p->mailbox);
       if ((r = mutt_yesorno (buf, M_YES)) == M_YES)
       {
+	if (is_numerical_keyid (keyID))
+	{
+	  if (strncmp (keyID, "0x", 2) == 0)
+	    keyID += 2;
+	  goto bypass_selection;		/* you don't see this. */
+	}
+	
 	/* check for e-mail address */
 	if ((t = strchr (keyID, '@')) && 
 	    (addr = rfc822_parse_adrlist (NULL, keyID)))
@@ -1090,7 +1111,7 @@ char *pgp_findKeys (ADDRESS *to, ADDRESS *cc, ADDRESS *bcc)
       }
       else if (r == -1)
       {
-	safe_free ((void **) &keylist);
+	FREE (&keylist);
 	rfc822_free_address (&tmp);
 	rfc822_free_address (&addr);
 	return NULL;
@@ -1107,7 +1128,7 @@ char *pgp_findKeys (ADDRESS *to, ADDRESS *cc, ADDRESS *bcc)
       if ((key = pgp_ask_for_key (buf, q->mailbox,
 				  KEYFLAG_CANENCRYPT, PGP_PUBRING)) == NULL)
       {
-	safe_free ((void **)&keylist);
+	FREE (&keylist);
 	rfc822_free_address (&tmp);
 	rfc822_free_address (&addr);
 	return NULL;
@@ -1118,6 +1139,7 @@ char *pgp_findKeys (ADDRESS *to, ADDRESS *cc, ADDRESS *bcc)
 
     keyID = pgp_keyid (key);
     
+  bypass_selection:
     keylist_size += mutt_strlen (keyID) + 4;
     safe_realloc ((void **)&keylist, keylist_size);
     sprintf (keylist + keylist_used, "%s0x%s", keylist_used ? " " : "",	/* __SPRINTF_CHECKED__ */
@@ -1346,7 +1368,7 @@ BODY *pgp_traditional_encryptsign (BODY *a, int flags, char *keylist)
   }
   
   unlink (pgperrfile);
-  
+
   if ((thepid = pgp_invoke_traditional (&pgpin, NULL, NULL, 
 					-1, fileno (pgpout), fileno (pgperr),
 					pgpinfile, keylist, flags)) == -1)
