@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2000 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1997-2000 Thomas Roessler <roessler@does-not-exist.org>
  * 
  *     This program is free software; you can redistribute it
  *     and/or modify it under the terms of the GNU General Public
@@ -242,10 +242,10 @@ pid_t pgp_invoke_traditional (FILE **pgpin, FILE **pgpout, FILE **pgperr,
 			      int pgpinfd, int pgpoutfd, int pgperrfd,
 			      const char *fname, const char *uids, int flags)
 {
-  if (flags & PGPENCRYPT)
+  if (flags & ENCRYPT)
     return pgp_invoke (pgpin, pgpout, pgperr, pgpinfd, pgpoutfd, pgperrfd,
-		       flags & PGPSIGN ? 1 : 0, fname, NULL, PgpSignAs, uids, 
-		       flags & PGPSIGN ? PgpEncryptSignCommand : PgpEncryptOnlyCommand);
+		       flags & SIGN ? 1 : 0, fname, NULL, PgpSignAs, uids, 
+		       flags & SIGN ? PgpEncryptSignCommand : PgpEncryptOnlyCommand);
   else
     return pgp_invoke (pgpin, pgpout, pgperr, pgpinfd, pgpoutfd, pgperrfd,
 		       1, fname, NULL, PgpSignAs, NULL,
@@ -331,12 +331,14 @@ pid_t pgp_invoke_list_keys (FILE **pgpin, FILE **pgpout, FILE **pgperr,
 {
   char uids[HUGE_STRING];
   char tmpuids[HUGE_STRING];
-
+  char quoted[HUGE_STRING];
+  
   *uids = '\0';
   
   for (; hints; hints = hints->next)
   {
-    snprintf (tmpuids, sizeof (tmpuids), "%s %s", uids, (char *) hints->data);
+    mutt_quote_filename (quoted, sizeof (quoted), (char *) hints->data);
+    snprintf (tmpuids, sizeof (tmpuids), "%s %s", uids, quoted);
     strcpy (uids, tmpuids);	/* __STRCPY_CHECKED__ */
   }
 
