@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1996,1997 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (c) 1998,1999 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1996,1997 Michael R. Elkins <me@mutt.org>
+ * Copyright (c) 1998,1999 Thomas Roessler <roessler@does-not-exist.org>
  * 
  *     This program is free software; you can redistribute it
  *     and/or modify it under the terms of the GNU General Public
@@ -605,17 +605,17 @@ static pgp_key_t *pgp_select_key (pgp_key_t *keys,
 	char buff[LONG_STRING];
 	
 	if (KeyTable[menu->current]->flags & KEYFLAG_CANTUSE)
-	  s = N_("This ID is expired/disabled/revoked");
+	  s = N_("ID is expired/disabled/revoked.");
 	else switch (KeyTable[menu->current]->trust & 0x03)
 	{
 	  case 0:
-	    s = N_("This ID's validity level is undefined.");
+	    s = N_("ID has undefined validity.");
 	    break;
 	  case 1:
-	    s = N_("This ID is not valid.");
+	    s = N_("ID is not valid.");
 	    break;
 	  case 2:
-	    s = N_("This ID is only marginally valid.");
+	    s = N_("ID is only marginally valid.");
 	    break;
 	}
 
@@ -646,7 +646,7 @@ static pgp_key_t *pgp_select_key (pgp_key_t *keys,
   }
 
   mutt_menuDestroy (&menu);
-  safe_free ((void **) &KeyTable);
+  FREE (&KeyTable);
 
   set_option (OPTNEEDREDRAW);
   
@@ -795,7 +795,7 @@ static LIST *pgp_add_string_to_hints (LIST *hints, const char *str)
       hints = mutt_add_list (hints, t);
   }
 
-  safe_free ((void **) &scratch);
+  FREE (&scratch);
   return hints;
 }
 
