@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1996,1997 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1996,1997 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@does-not-exist.org>
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -19,10 +19,12 @@
 
 #ifdef HAVE_PGP
 
-#define PGPENCRYPT  (1 << 0)
-#define PGPSIGN     (1 << 1)
-#define PGPKEY      (1 << 2)
-#define PGPGOODSIGN (1 << 3)
+#define APPLICATION_PGP  (1 << 5)
+
+#define PGPENCRYPT  (APPLICATION_PGP | ENCRYPT)
+#define PGPSIGN     (APPLICATION_PGP | SIGN)
+#define PGPGOODSIGN (APPLICATION_PGP | GOODSIGN)
+#define PGPKEY      (APPLICATION_PGP | (1 << 3))
 
 #define KEYFLAG_CANSIGN 		(1 <<  0)
 #define KEYFLAG_CANENCRYPT 		(1 <<  1)
@@ -40,6 +42,15 @@
 
 #define KEYFLAG_ABILITIES (KEYFLAG_CANSIGN|KEYFLAG_CANENCRYPT|KEYFLAG_PREFER_ENCRYPTION|KEYFLAG_PREFER_SIGNING)
 
+typedef struct pgp_signature
+{
+  struct pgp_signature *next;
+  unsigned char sigtype;
+  unsigned long sid1;
+  unsigned long sid2;
+}
+pgp_sig_t;
+
 typedef struct pgp_keyinfo
 {
   char *keyid;
@@ -50,7 +61,15 @@ typedef struct pgp_keyinfo
   int numalg;
   const char *algorithm;
   struct pgp_keyinfo *parent;
+  struct pgp_signature *sigs;
   struct pgp_keyinfo *next;
+
+  short fp_len;			  /* length of fingerprint.
+				   * 20 for sha-1, 16 for md5.
+				   */
+  unsigned char fingerprint[20];  /* large enough to hold SHA-1 and RIPEMD160
+                                     hashes (20 bytes), MD5 hashes just use the
+                                     first 16 bytes */
 }
 pgp_key_t;
 
@@ -61,6 +80,7 @@ typedef struct pgp_uid
   int flags;
   struct pgp_keyinfo *parent;
   struct pgp_uid *next;
+  struct pgp_signature *sigs;
 }
 pgp_uid_t;
 
