@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Vsevolod Volkov <vvv@mutt.org.ua>
+ * Copyright (C) 2000-2002 Vsevolod Volkov <vvv@mutt.org.ua>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -24,6 +24,10 @@
 #include "pgp.h"
 #endif
 
+#ifdef HAVE_SMIME
+#include "smime.h"
+#endif
+
 #include <string.h>
 #include <unistd.h>
 
@@ -236,13 +240,14 @@ int pop_open_mailbox (CONTEXT *ctx)
 {
   int ret;
   char buf[LONG_STRING];
+  CONNECTION *conn;
   ACCOUNT acct;
   POP_DATA *pop_data;
   ciss_url_t url;
 
   if (pop_parse_path (ctx->path, &acct))
   {
-    mutt_error ("%s is an invalid POP path", ctx->path);
+    mutt_error (_("%s is an invalid POP path"), ctx->path);
     mutt_sleep (2);
     return -1;
   }
@@ -250,18 +255,21 @@ int pop_open_mailbox (CONTEXT *ctx)
   mutt_account_tourl (&acct, &url);
   url.path = NULL;
   url_ciss_tostring (&url, buf, sizeof (buf), 0);
+  conn = mutt_conn_find (NULL, &acct);
+  if (!conn)
+    return -1;
 
   FREE (&ctx->path);
   ctx->path = safe_strdup (buf);
 
   pop_data = safe_calloc (1, sizeof (POP_DATA));
-  pop_data->conn = mutt_conn_find (NULL, &acct);
+  pop_data->conn = conn;
   ctx->data = pop_data;
 
   if (pop_open_connection (pop_data) < 0)
     return -1;
 
-  pop_data->conn->data = pop_data;
+  conn->data = pop_data;
 
   FOREVER
   {
@@ -300,7 +308,7 @@ static void pop_clear_cache (POP_DATA *pop_data)
     if (pop_data->cache[i].path)
     {
       unlink (pop_data->cache[i].path);
-      safe_free ((void **) &pop_data->cache[i].path);
+      FREE (&pop_data->cache[i].path);
     }
   }
 }
@@ -434,9 +442,9 @@ int pop_fetch_message (MESSAGE* msg, CONTEXT* ctx, int msgno)
   h->content->length = ftell (msg->fp) - h->content->offset;
 
   /* This needs to be done in case this is a multipart message */
-#ifdef HAVE_PGP
-  h->pgp = pgp_query (h->content);
-#endif /* HAVE_PGP */
+#if defined(HAVE_PGP) || defined(HAVE_SMIME)
+  h->security = crypt_query (h->content);
+#endif
 
   mutt_clear_error();
   rewind (msg->fp);
@@ -531,6 +539,7 @@ void pop_fetch_mail (void)
   char msgbuf[SHORT_STRING];
   char *url, *p;
   int i, delanswer, last = 0, msgs, bytes, rset = 0, ret;
+  CONNECTION *conn;
   CONTEXT ctx;
   MESSAGE *msg = NULL;
   ACCOUNT acct;
@@ -550,19 +559,29 @@ void pop_fetch_mail (void)
   }
   strcpy (p, PopHost);		/* __STRCPY_CHECKED__ */
 
-  if (pop_parse_path (url, &acct))
+  ret = pop_parse_path (url, &acct);
+  FREE (&url);
+  if (ret)
   {
-    mutt_error ("%s is an invalid POP path", PopHost);
+    mutt_error (_("%s is an invalid POP path"), PopHost);
     return;
   }
 
-  pop_data = safe_calloc (1, sizeof (POP_DATA));
-  pop_data->conn = mutt_conn_find (NULL, &acct);
-
-  if (pop_open_connection (pop_data) < 0)
+  conn = mutt_conn_find (NULL, &acct);
+  if (!conn)
     return;
 
-  pop_data->conn->data = pop_data;
+  pop_data = safe_calloc (1, sizeof (POP_DATA));
+  pop_data->conn = conn;
+
+  if (pop_open_connection (pop_data) < 0)
+  {
+    mutt_socket_free (pop_data->conn);
+    FREE (&pop_data);
+    return;
+  }
+
+  conn->data = pop_data;
 
   mutt_message _("Checking for new messages...");
 
@@ -665,12 +684,12 @@ finish:
   strfcpy (buffer, "QUIT\r\n", sizeof (buffer));
   if (pop_query (pop_data, buffer, sizeof (buffer)) == -1)
     goto fail;
-  mutt_socket_close (pop_data->conn);
+  mutt_socket_close (conn);
   FREE (&pop_data);
   return;
 
 fail:
   mutt_error _("Server closed connection!");
-  mutt_socket_close (pop_data->conn);
+  mutt_socket_close (conn);
   FREE (&pop_data);
 }
