@@ -33,7 +33,7 @@
 
 #ifdef USE_SASL
 /* SASL authenticator */
-static pop_auth_res_t pop_auth_sasl (POP_DATA *pop_data)
+static pop_auth_res_t pop_auth_sasl (POP_DATA *pop_data, const char *method)
 {
   sasl_conn_t *saslconn;
   sasl_interact_t *interaction = NULL;
@@ -51,9 +51,12 @@ static pop_auth_res_t pop_auth_sasl (POP_DATA *pop_data)
     return POP_A_FAILURE;
   }
 
+  if (!method)
+    method = pop_data->auth_list;
+
   FOREVER
   {
-    rc = sasl_client_start (saslconn, pop_data->auth_list, NULL,
+    rc = sasl_client_start (saslconn, method, NULL,
 			    &interaction, &pc, &olen, &mech);
     if (rc != SASL_INTERACT)
       break;
@@ -124,7 +127,7 @@ static pop_auth_res_t pop_auth_sasl (POP_DATA *pop_data)
 
       /* sasl_client_st(art|ep) allocate pc with malloc, expect me to 
        * free it */
-      safe_free ((void *) &pc);
+      FREE (&pc);
     }
   }
 
@@ -170,7 +173,7 @@ void pop_apop_timestamp (POP_DATA *pop_data, char *buf)
 }
 
 /* APOP authenticator */
-static pop_auth_res_t pop_auth_apop (POP_DATA *pop_data)
+static pop_auth_res_t pop_auth_apop (POP_DATA *pop_data, const char *method)
 {
   MD5_CTX mdContext;
   unsigned char digest[16];
@@ -212,7 +215,7 @@ static pop_auth_res_t pop_auth_apop (POP_DATA *pop_data)
 }
 
 /* USER authenticator */
-static pop_auth_res_t pop_auth_user (POP_DATA *pop_data)
+static pop_auth_res_t pop_auth_user (POP_DATA *pop_data, const char *method)
 {
   char buf[LONG_STRING];
   int ret;
@@ -356,13 +359,13 @@ int pop_authenticate (POP_DATA* pop_data)
 
     while (authenticator->authenticate)
     {
-      ret = authenticator->authenticate (pop_data, method);
+      ret = authenticator->authenticate (pop_data, authenticator->method);
       if (ret == POP_A_SOCKET)
 	switch (pop_connect (pop_data))
 	{
 	  case 0:
 	  {
-	    ret = authenticator->authenticate (pop_data, method);
+	    ret = authenticator->authenticate (pop_data, authenticator->method);
 	    break;
 	  }
 	  case -2:
@@ -373,10 +376,7 @@ int pop_authenticate (POP_DATA* pop_data)
 	attempts++;
       if (ret == POP_A_SUCCESS || ret == POP_A_SOCKET ||
 	  (ret == POP_A_FAILURE && !option (OPTPOPAUTHTRYALL)))
-      {
-	comma = NULL;
 	break;
-      }
 
       authenticator++;
     }
