@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@does-not-exist.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -1150,12 +1150,12 @@ void mutt_view_attachments (HEADER *hdr)
 	    continue;
 	  if (idx[idxmax]->content && idx[idxmax]->content->deleted)
 	    hdr->attach_del = 1;
-	  safe_free ((void **) &idx[idxmax]->tree);
-	  safe_free ((void **) &idx[idxmax]);
+	  FREE (&idx[idxmax]->tree);
+	  FREE (&idx[idxmax]);
 	}
 	if (hdr->attach_del)
 	  hdr->changed = 1;
-	safe_free ((void **) &idx);
+	FREE (&idx);
 	idxmax = 0;
 
 
