@@ -1039,6 +1039,7 @@ ci_send_message (int flags,		/* send mode */
   BODY *pbody;
   int i, killfrom = 0;
   int fcc_error = 0;
+  int free_clear_content = 0;
 
 #if defined(HAVE_PGP) || defined(HAVE_SMIME)
   BODY *save_content = NULL;
@@ -1250,9 +1251,9 @@ ci_send_message (int flags,		/* send mode */
 	msg->security |= SIGN;
       if (option (OPTCRYPTAUTOENCRYPT))
 	msg->security |= ENCRYPT;
-      if (option (OPTCRYPTREPLYENCRYPT) && cur && cur->security & ENCRYPT)
+      if (option (OPTCRYPTREPLYENCRYPT) && cur && (cur->security & ENCRYPT))
 	msg->security |= ENCRYPT;
-      if (option (OPTCRYPTREPLYSIGN) && cur && cur->security & SIGN)
+      if (option (OPTCRYPTREPLYSIGN) && cur && (cur->security & SIGN))
 	msg->security |= SIGN;
       if (option (OPTCRYPTREPLYSIGNENCRYPTED) && cur && cur->security & ENCRYPT)
 	msg->security |= SIGN;
@@ -1261,20 +1262,19 @@ ci_send_message (int flags,		/* send mode */
     if (msg->security && cur)
     {
 #ifdef HAVE_SMIME
-      if (cur->security & APPLICATION_SMIME || option (OPTSMIMEISDEFAULT))
+      if ((cur->security & APPLICATION_SMIME) || option (OPTSMIMEISDEFAULT))
         msg->security |= APPLICATION_SMIME;
 #endif
 #ifdef HAVE_PGP
       if (cur->security & APPLICATION_PGP)
       {
 #ifdef HAVE_SMIME
-        if (option (OPTSMIMEISDEFAULT))
-          msg->security &= ~APPLICATION_SMIME;
+	msg->security &= ~APPLICATION_SMIME;
 #endif
         msg->security |= APPLICATION_PGP;
       }
 #ifdef HAVE_SMIME
-      if (~cur->security && !option (OPTSMIMEISDEFAULT))
+      if (!(cur->security & (APPLICATION_PGP|APPLICATION_SMIME)))
 #endif
 	msg->security |= APPLICATION_PGP;
 #endif /* HAVE_PGP */
@@ -1492,6 +1492,12 @@ main_loop:
    * - something else.  In this case, it's the same as clear_content.
    */
 
+  /* This is ugly -- lack of "reporting back" from mutt_protect(). */
+  
+  if (clear_content && (msg->content != clear_content)
+      && (msg->content->parts != clear_content))
+    free_clear_content = 1;
+  
 #endif /* HAVE_PGP */
 
   if (!option (OPTNOCURSES) && !(flags & SENDMAILX))
@@ -1652,11 +1658,10 @@ full_fcc:
 
 #if defined(HAVE_PGP) || defined(HAVE_SMIME)
   if (msg->security & ENCRYPT)
-  {
-    /* cleanup structures from the first encryption */
-    mutt_free_body (&clear_content);
     FREE (&pgpkeylist);
-  }
+  
+  if (free_clear_content)
+    mutt_free_body (&clear_content);
 #endif
 
   if (flags & SENDREPLY)
@@ -1684,7 +1689,7 @@ cleanup:
     
     if(signas)
     {
-      safe_free((void **) &PgpSignAs);
+      FREE (&PgpSignAs);
       PgpSignAs = signas;
     }
   }
