@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -207,6 +207,14 @@ void mutt_sort_headers (CONTEXT *ctx, int init)
   }
   unset_option (OPTNEEDRESCORE);
 
+  if (option (OPTRESORTINIT))
+  {
+    unset_option (OPTRESORTINIT);
+    init = 1;
+  }
+
+  if (init && ctx->tree)
+    mutt_clear_threads (ctx);
 
   if ((Sort & SORT_MASK) == SORT_THREADS)
   {
@@ -222,11 +230,6 @@ void mutt_sort_headers (CONTEXT *ctx, int init)
       Sort = i;
       unset_option (OPTSORTSUBTHREADS);
     }
-    if (option (OPTRESORTINIT))
-    {
-      unset_option (OPTRESORTINIT);
-      init = 1;
-    }
     mutt_sort_threads (ctx, init);
   }
   else if ((sortfunc = mutt_get_sort_func (Sort)) == NULL ||
